@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 /// A single line in a recipe body, consisting of any number of `Fragment`s.
 #[derive(Debug, Clone, PartialEq, Serialize)]
