@@ -185,7 +185,7 @@ pub enum Expression {
     name: String,
     arguments: Vec<Expression>,
   },
-  Concatination {
+  Concatenation {
     lhs: Box<Expression>,
     rhs: Box<Expression>,
   },
@@ -196,6 +196,10 @@ pub enum Expression {
     otherwise: Box<Expression>,
     operator: ConditionalOperator,
   },
+  Join {
+    lhs: Box<Expression>,
+    rhs: Box<Expression>,
+  },
   String {
     text: String,
   },
@@ -249,7 +253,11 @@ impl Expression {
           arguments: vec![Expression::new(a), Expression::new(b), Expression::new(c)],
         },
       },
-      Concatination { lhs, rhs } => Expression::Concatination {
+      Concatenation { lhs, rhs } => Expression::Concatenation {
+        lhs: Box::new(Expression::new(lhs)),
+        rhs: Box::new(Expression::new(rhs)),
+      },
+      Join { lhs, rhs } => Expression::Join {
         lhs: Box::new(Expression::new(lhs)),
         rhs: Box::new(Expression::new(rhs)),
       },
