@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 fn test(justfile: &str, value: Value) {
   Test::new()
@@ -45,6 +45,7 @@ fn alias() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -73,6 +74,7 @@ fn assignment() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -114,6 +116,7 @@ fn body() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -165,6 +168,7 @@ fn dependencies() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -253,6 +257,7 @@ fn dependency_argument() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -305,6 +310,7 @@ fn duplicate_recipes() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -339,6 +345,7 @@ fn doc_comment() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -361,6 +368,7 @@ fn empty_justfile() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -492,6 +500,7 @@ fn parameters() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -562,6 +571,7 @@ fn priors() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -596,6 +606,7 @@ fn private() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -630,6 +641,7 @@ fn quiet() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -685,6 +697,7 @@ fn settings() {
           "command": "a",
         },
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -722,6 +735,7 @@ fn shebang() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
@@ -756,6 +770,7 @@ fn simple() {
         "positional_arguments": false,
         "shell": null,
         "windows_powershell": false,
+        "windows_shell": null,
       },
       "warnings": [],
     }),
